@@ -10,8 +10,8 @@ class NoClassificationError (Exception):
 
 class MissingLabelError(Exception):
     """
-    Raised by ClassifierCollection.classify when requested classifier labels
-    are missing from collection.
+    Raised by ClassifyDescriptorCollection.classify when requested classifier
+    labels are missing from collection.
     """
     def __init__(self, labels: Set[str]):
         """
@@ -19,3 +19,11 @@ class MissingLabelError(Exception):
         """
         super(MissingLabelError, self).__init__(labels)
         self.labels = labels
+
+
+class ExistingModelError(Exception):
+    """
+    Raised by ClassifyDescriptorSupervised and ClassifyImageSupervised when
+    a model already exists in an instance to prevent overwriting and existing
+    model
+    """
