@@ -53,20 +53,21 @@ class SkLearnLogisticRegression (LogisticRegression, ClassifyDescriptorSupervise
     ) -> None:
         # convert descriptor elements into combines ndarray with associated
         # label vector.
-        vec_list = []
+        vec_list: list[np.ndarray] = []
         label_list = []
         for label, examples in class_examples.items():
             label_vectors = \
                 DescriptorElement.get_many_vectors(examples)
             # ``is`` or ``count`` method messes up when elements are np arrays.
-            none_count = len([e for e in label_vectors if e is None])
+            cleaned_labels = [e for e in label_vectors if e is not None]
+            none_count = len(label_vectors) - len(cleaned_labels)
             assert none_count == 0, \
                 "Some descriptor elements for label {} did not contain " \
                 "vectors! (n={})".format(label, none_count)
-            vec_list.extend(label_vectors)
-            label_list.extend([label] * len(label_vectors))
-        vec_list = np.vstack(vec_list)
-        self.fit(vec_list, label_list)
+            vec_list.extend(cleaned_labels)
+            label_list.extend([label] * len(cleaned_labels))
+        vec_stack = np.vstack(vec_list)
+        self.fit(vec_stack, label_list)
 
     def _classify_arrays(self, array_iter: Union[np.ndarray, Iterable[np.ndarray]]) -> Iterator[Dict[Hashable, float]]:
         # Collect arrays for prediction.
